@@ -1,11 +1,11 @@
 package App::PAUSE::CheckPerms;
-$App::PAUSE::CheckPerms::VERSION = '0.04';
+$App::PAUSE::CheckPerms::VERSION = '0.05';
 use 5.010;
 use Moo;
 use MooX::Options;
 
 use PAUSE::Permissions 0.06;
-use PAUSE::Packages 0.02;
+use PAUSE::Packages 0.07;
 
 option 'user'      => (is => 'ro', format => 's');
 
@@ -24,7 +24,7 @@ sub execute
     my $bad_count = 0;
 
     RELEASE:
-    while (my $release = $release_iterator->next) {
+    while (my $release = $release_iterator->next_release) {
         if ($self->user) {
             my $seen_user = 0;
             my $USER      = uc($self->user);
